@@ -1,6 +1,6 @@
 package Email::MIME::Kit::Assembler::Standard;
 # ABSTRACT: the standard kit assembler
-$Email::MIME::Kit::Assembler::Standard::VERSION = '2.102015';
+$Email::MIME::Kit::Assembler::Standard::VERSION = '3.000001';
 use Moose;
 use Moose::Util::TypeConstraints;
 
@@ -70,25 +70,18 @@ sub assemble {
 sub _assemble_from_string {
   my ($self, $body, $stash) = @_;
 
-  # I really shouldn't have to do this, but I'm not going to go screw around
-  # with @#$@#$ Email::Simple/MIME just to deal with it right now. -- rjbs,
-  # 2009-01-19
-  $body .= "\x0d\x0a" unless $body =~ /[\x0d|\x0a]\z/;
-
-  my $body_ref = $self->render(\$body, $stash);
-
   my %attr = %{ $self->manifest->{attributes} || {} };
-  $attr{content_type} = $attr{content_type} || 'text/plain';
+  $attr{content_type} ||= 'text/plain';
 
-  if ($$body_ref =~ /[\x80-\xff]/) {
-    if ($attr{content_type} =~ m{^text/}) {
-      $attr{encoding} ||= 'quoted-printable';
-      $attr{charset}  ||= 'utf-8'
-    } else {
-      $attr{encoding} ||= 'base64';
-    }
+  if ($attr{content_type} =~ m{^text/}) {
+    # I really shouldn't have to do this, but I'm not going to go screw around
+    # with @#$@#$ Email::Simple/MIME just to deal with it right now. -- rjbs,
+    # 2009-01-19
+    $body .= "\x0d\x0a" unless $body =~ /[\x0d|\x0a]\z/;
   }
 
+  my $body_ref  = $self->render(\$body, $stash);
+
   my $email = $self->_contain_attachments({
     attributes => \%attr,
     header     => $self->manifest->{header},
@@ -110,7 +103,10 @@ sub _assemble_from_manifest_body {
 sub _assemble_from_kit {
   my ($self, $stash) = @_;
 
-  my $body_ref = $self->kit->get_kit_entry($self->manifest->{path});
+  my $type   = $self->manifest->{attributes}{content_type} || 'text/plain';
+  my $method = $type =~ m{^text/} ? 'get_decoded_kit_entry' : 'get_kit_entry';
+
+  my $body_ref = $self->kit->$method($self->manifest->{path});
 
   $self->_assemble_from_string($$body_ref, $stash);
 }
@@ -275,20 +271,32 @@ sub _contain_attachments {
 
   my $ct = $arg->{container_type};
 
+  my %attr = %{ $arg->{attributes} };
+  my $body_type = 'body';
+
+  if ($attr{content_type} =~ m{^text/}) {
+    $body_type = 'body_str';
+
+    $attr{encoding} ||= 'quoted-printable';
+    $attr{charset}  ||= 'UTF-8'
+  } elsif (($arg->{body} || '') =~ /\P{ASCII}/) {
+    $attr{encoding} ||= 'base64';
+  }
+
   unless (@attachments) {
     confess "container_type given for single-part assembly" if $ct;
 
     return Email::MIME->create(
-      attributes => $arg->{attributes},
+      attributes => \%attr,
       header_str => $header,
-      body       => $arg->{body},
+      $body_type => $arg->{body},
       parts      => $arg->{parts},
     );
   }
 
   my $email = Email::MIME->create(
-    attributes => $arg->{attributes},
-    body       => $arg->{body},
+    attributes => \%attr,
+    $body_type => $arg->{body},
     parts      => $arg->{parts},
   );
 
@@ -356,7 +364,7 @@ Email::MIME::Kit::Assembler::Standard - the standard kit assembler
 
 =head1 VERSION
 
-version 2.102015
+version 3.000001
 
 =head1 WARNING
 
